@@ -9,7 +9,7 @@ from sqlalchemy.dialects import postgresql, mysql, mssql
 import sqlalchemy as sa
 
 from .exceptions import ModelConversionError
-from .fields import Related
+from .fields import Related, RelatedList
 
 def _is_field(value):
     return (
@@ -36,13 +36,6 @@ def _postgres_array_factory(converter, data_type):
         converter._get_field_class_for_data_type(data_type.item_type),
     )
 
-def _should_exclude_field(column, fields=None, exclude=None):
-    if fields and column.key not in fields:
-        return True
-    if exclude and column.key in exclude:
-        return True
-    return False
-
 class ModelConverter(object):
     """Class that converts a SQLAlchemy model into a dictionary of corresponding
     marshmallow `Fields <marshmallow.fields.Field>`.
@@ -86,12 +79,14 @@ class ModelConverter(object):
         else:
             return ma.Schema.TYPE_MAPPING
 
-    def fields_for_model(self, model, include_fk=False, fields=None, exclude=None, base_fields=None,
-                         dict_cls=dict):
+    def fields_for_model(
+        self, model, include_fk=False, fields=None, exclude=None, base_fields=None,
+        dict_cls=dict,
+    ):
         result = dict_cls()
         base_fields = base_fields or {}
         for prop in model.__mapper__.iterate_properties:
-            if _should_exclude_field(prop, fields=fields, exclude=exclude):
+            if self._should_exclude_field(prop, fields=fields, exclude=exclude):
                 # Allow marshmallow to validate and exclude the field key.
                 result[prop.key] = None
                 continue
@@ -109,12 +104,14 @@ class ModelConverter(object):
                 result[prop.key] = field
         return result
 
-    def fields_for_table(self, table, include_fk=False, fields=None, exclude=None, base_fields=None,
-                         dict_cls=dict):
+    def fields_for_table(
+        self, table, include_fk=False, fields=None, exclude=None, base_fields=None,
+        dict_cls=dict,
+    ):
         result = dict_cls()
         base_fields = base_fields or {}
         for column in table.columns:
-            if _should_exclude_field(column, fields=fields, exclude=exclude):
+            if self._should_exclude_field(column, fields=fields, exclude=exclude):
                 continue
             if not include_fk and column.foreign_keys:
                 continue
@@ -135,7 +132,7 @@ class ModelConverter(object):
             self.DIRECTION_MAPPING[prop.direction.name] and
             prop.uselist is True
         ):
-            ret = fields.List(ret, **kwargs)
+            ret = RelatedList(ret, **kwargs)
         return ret
 
     def column2field(self, column, instance=True, **kwargs):
@@ -177,7 +174,8 @@ class ModelConverter(object):
                 if hasattr(data_type, 'impl'):
                     return self._get_field_class_for_data_type(data_type.impl)
                 raise ModelConversionError(
-                    'Could not find field column of type {0}.'.format(types[0]))
+                    'Could not find field column of type {0}.'.format(types[0]),
+                )
         return field_cls
 
     def _get_field_class_for_property(self, prop):
@@ -188,15 +186,33 @@ class ModelConverter(object):
             field_cls = self._get_field_class_for_column(column)
         return field_cls
 
+    def _merge_validators(self, defaults, new):
+        new_classes = [validator.__class__ for validator in new]
+        return [
+            validator
+            for validator in defaults
+            if validator.__class__ not in new_classes
+        ] + new
+
     def _get_field_kwargs_for_property(self, prop):
         kwargs = self.get_base_kwargs()
         if hasattr(prop, 'columns'):
             column = prop.columns[0]
             self._add_column_kwargs(kwargs, column)
+            prop = column
         if hasattr(prop, 'direction'):  # Relationship property
             self._add_relationship_kwargs(kwargs, prop)
         if getattr(prop, 'doc', None):  # Useful for documentation generation
             kwargs['description'] = prop.doc
+        info = getattr(prop, 'info', dict())
+        overrides = info.get('marshmallow')
+        if overrides is not None:
+            validate = overrides.pop('validate', [])
+            kwargs['validate'] = self._merge_validators(
+                kwargs['validate'],
+                validate,
+            )  # Ensure we do not override the generated validators.
+            kwargs.update(overrides)  # Override other kwargs.
         return kwargs
 
     def _add_column_kwargs(self, kwargs, column):
@@ -239,11 +255,19 @@ class ModelConverter(object):
             'required': not nullable,
         })
 
+    def _should_exclude_field(self, column, fields=None, exclude=None):
+        if fields and column.key not in fields:
+            return True
+        if exclude and column.key in exclude:
+            return True
+        return False
+
     def get_base_kwargs(self):
         return {
-            'validate': []
+            'validate': [],
         }
 
+
 default_converter = ModelConverter()
 
 fields_for_model = default_converter.fields_for_model
